diff graal/com.oracle.truffle.api/src/com/oracle/truffle/api/instrument/Probe.java @ 16391:50d79ad439f1

Truffle/Instrumentation: rename PhylumTag to SyntaxTag (along with related classes/methods)
author Michael Van De Vanter <michael.van.de.vanter@oracle.com>
date Wed, 02 Jul 2014 16:06:42 -0700
parents 915ebb306fcc
children 7833417c8172
line wrap: on
line diff
--- a/graal/com.oracle.truffle.api/src/com/oracle/truffle/api/instrument/Probe.java	Wed Jul 02 23:40:19 2014 +0200
+++ b/graal/com.oracle.truffle.api/src/com/oracle/truffle/api/instrument/Probe.java	Wed Jul 02 16:06:42 2014 -0700
@@ -32,7 +32,7 @@
  * associated with programmer-facing tools, there should be no more than one probe associated with a
  * particular piece of source code syntax (i.e. a {@link SourceSection}).
  * <p>
  * Any {@linkplain PhylumTag tags} associated with a particular piece of source code syntax are
  * managed by the probe.
  * <p>
  * When ASTs are copied, it is presumed that the probe for a site is shared by all AST nodes
@@ -52,7 +52,7 @@
  * @see Instrument
  * @see Wrapper
  */
-public interface Probe extends ExecutionEvents, PhylumTagged {
+public interface Probe extends ExecutionEvents, SyntaxTagged {
 
     /**
      * The source location with which this probe is (presumably uniquely) associated.
@@ -63,7 +63,7 @@
      * Mark this probe as being associated with an AST node in some category useful for debugging
      * and other tools.
      */
-    void tagAs(PhylumTag tag);
+    void tagAs(SyntaxTag tag);
 
     /**
      * Adds an instrument to this probe.
@@ -32,7 +32,7 @@
  * particular piece of source code syntax (i.e. a {@link SourceSection}).
  * <p>
- * Any {@linkplain PhylumTag tags} associated with a particular piece of source code syntax are
+ * Any {@linkplain SyntaxTag tags} associated with a particular piece of source code syntax are
  * managed by the probe.
  * <p>